package maxflow;

import java.util.*;
import java.io.*;

class Graph
{
    public static final int INFINITY = Integer.MAX_VALUE;
    private HashMap<String,Vertex> vertexMap = new HashMap<String,Vertex>( );    // Maps vertices to internal Vertex

    public void addEdge( String sourceName, int cost, String destName )
    {
        Vertex v = getVertex( sourceName );
        Vertex w = getVertex( destName );
        Edge e = new Edge(cost,w);
        v.adj.add( e );
    }


      // If vertexName is not present, add it to vertexMap.
      // In either case, return the Vertex.
    private Vertex getVertex( String vertexName )
    {
        Vertex v = (Vertex) vertexMap.get( vertexName );
        if( v == null )
        {
            v = new Vertex( vertexName );
            vertexMap.put( vertexName, v );
        }
        return v;
    }


    public int maxflow( String startName, String destName ) throws NoSuchElementException
    {
    	return 0;	
    }

    /**
     * Process a request; return false if end of file.
     */
    public static boolean processRequest( BufferedReader in, Graph g )
    {
        String startName = null;
        String destName = null;

        try
        {
            System.out.println( "Enter start node:" );
            if( ( startName = in.readLine( ) ) == null )
                return false;
            System.out.println( "Enter destination node:" );
            if( ( destName = in.readLine( ) ) == null )
                return false;

            int flow = g.maxflow( startName, destName );
            System.out.println("Max flow is: " + flow);
        }
        catch( Exception e )
          { System.err.println( e ); }
        return true;
    }

    public static void main( String [ ] args )
    {
        Graph g = new Graph( );
        try
        {
            FileReader fin = new FileReader( args[0] );
            BufferedReader graphFile = new BufferedReader( fin );

            // Read the edges and insert
            String line;
            while( ( line = graphFile.readLine( ) ) != null )
            {
                StringTokenizer st = new StringTokenizer( line );

                try
                {
                    if( st.countTokens( ) != 3 )
                        throw new Exception( );
                    String source  = st.nextToken( );
                    String dest    = st.nextToken( );
                    int cost    = Integer.parseInt(st.nextToken( ));
                    g.addEdge( source, cost, dest );
                }
                catch( Exception e )
                  { System.err.println( e + " " + line ); }
             }
         }
         catch( Exception e )
           { System.err.println( e ); }

         System.out.println( "File read" );

         BufferedReader in = new BufferedReader( new InputStreamReader( System.in ) );
         while( processRequest( in, g ) )
             ;
    }
}

